<?php

/**
 * Format the teaser for a tracknstack node.
 */
function theme_tracknstack_teaser($node) {
  $items = array();

  if (module_exists('jplayer') && $node->tracknstack->mp3_mixdown_fid) {
    $element['#item']['fid'] = $node->tracknstack->mp3_mixdown_fid;
    $items[] = theme('jplayer_formatter_single', $element);
  }

  if ($node->tracknstack->tempo) {
    $items[] = '<strong>' . t('Tempo') . ':</strong> ' . $node->tracknstack->tempo . ' ' . t('BPM');
  }

  if ($node->tracknstack->beats_per_measure && $node->tracknstack->beat_value) {
    $items[] = '<strong>' . t('Time signature') . ':</strong> ' . $node->tracknstack->beats_per_measure . '/' . $node->tracknstack->beat_value;
  }

  if ($node->tracknstack->main_key) {
    $items[] = '<strong>' . t('Main key') . ':</strong> ' . $node->tracknstack->main_key;
  }

  if (user_access('access tracknstack')) {
    $mixdown_links = array();

    if ($node->tracknstack->mixdown_fid) {
      $file = tracknstack_file_load($node->tracknstack->mixdown_fid);
      $file_extension = tracknstack_get_filename_extension($file->filename);
      $mixdown_url = tracknstack_get_base_url() . '?q=tracknstack/mixdownload/' . $node->nid;
      $mixdown_links[] = l($file_extension, $mixdown_url, array('attributes' => array('title' => t('Download ' . $file_extension . ' mixdown.'))));
    }

    if ($node->tracknstack->wav_mixdown_fid && $node->tracknstack->mixdown_fid != $node->tracknstack->wav_mixdown_fid) {
      $file = tracknstack_file_load($node->tracknstack->wav_mixdown_fid);
      $file_extension = tracknstack_get_filename_extension($file->filename);
      $mixdown_url = tracknstack_get_base_url() . '?q=tracknstack/mixdownload/' . $node->nid . '/true';
      $mixdown_links[] = l($file_extension, $mixdown_url, array('attributes' => array('title' => t('Download ' . $file_extension . ' mixdown.'))));
    }

    if (sizeof($mixdown_links) > 0) {
      foreach  ($mixdown_links as $mixdown_link) {
        if ($mixdown_item) {
          $mixdown_item .= ', ';
        }

        $mixdown_item .= $mixdown_link;
      }

      $items[] = '<strong>' . t('Mixdown') . ':</strong> ' . $mixdown_item;
    }
    else {
      $items[] = t('Processing mixdown...');
    }
  }

  return theme('item_list', $items);
}

/**
 * Format the tracknstack node for display
 */
function theme_tracknstack_display($node) {
  global $user;

  $output = theme('tracknstack_teaser', $node);

  if ($node->tracknstack_checkin) {
    $cicount = sizeof($node->tracknstack_checkin);

    $is_view_allowed = $cicount > 0;

    if ($is_view_allowed) {
      $headers = array(t('Checkin Date'), t('Username'), t('Files'), '');

      $rows = array();

      $is_delete_allowed = $user->uid == $node->uid || user_access('delete tracknstack files');

      $actions_delete_html = '<img src="';
      $actions_delete_html .= base_path() . drupal_get_path("module", "tracknstack") . '/images/delete.png';
      $actions_delete_html .= '" title="';
      $actions_delete_html .= t('Delete file.');
      $actions_delete_html .= '"/>';

      $base_url = tracknstack_get_base_url();

      for ($i = $cicount - 1; $checkin = $node->tracknstack_checkin[$i]; $i--) {
        $ciuser = tracknstack_get_user($checkin->uid);

        $cifilecount = sizeof($checkin->files);
        $is_download_allowed = user_access('download tracknstack files');

        $files_html = '';
        $actions_html = '';

        for ($j = $cifilecount - 1; $file = $checkin->files[$j]; $j--) {
          $filename = check_plain(tracknstack_get_filename($file, $node));

          if ($is_download_allowed || $checkin->uid == $user->uid) {
            $files_html .= l($filename, $base_url . '?q=tracknstack/download/' . $file->fid, array('attributes' => array('title' => t('Download file.'))));
          } else {
            $files_html .= $filename;
          }

          $files_html .= '<br/>';

          if ($is_delete_allowed || $checkin->uid == $user->uid) {
            $actions_html .= l($actions_delete_html, $base_url . '?q=tracknstack/delete_file/' . $file->fid, array('html' => true));
            $actions_html .= '<br/>';
          }
        }

        $row_values = array(format_date($checkin->datein), theme('username', $ciuser), $files_html, $actions_html);

        $rows[] = array(
          'data' => $row_values,
          'style' => 'vertical-align:top'
        );
      }
    }

    $output .= theme_table($headers, $rows);
  }

  return $output;
}